@@ -44,19 +44,18 @@ class AnomalyDetection():
         self.performance_df = 0
             
     
-        #python_version = al.platform.python_version()
-        #splitted_version = python_version.split('.')
-        #joined_version = float('.'.join(splitted_version[0:2]))
-        #if self.models == ['full'] or 'TADGAN' in models:
-        #    if joined_version > 3.7:
-        #        print(f"Using Python's current version {python_version} it won't be possible to fit TADGAN, for that you need Python 3.7 \n Skipping TADGAN")
-        #        self.models = self.models.remove('TADGAN')
-        #    else:
-        #        print("All good we can run on a full speed!")
-        #        self.models = ['dbscan', 'iforest', 'ThymeBoost', 'ocsvm', 'lof']#, 'tadgan']
+        python_version = al.platform.python_version()
+        splitted_version = python_version.split('.')
+        joined_version = float('.'.join(splitted_version[0:2]))
+        if self.models == ['full'] or 'TADGAN' in models:
+            if joined_version > 3.7:
+                print(f"Using Python's current version {python_version} it won't be possible to fit TADGAN, for that you need Python 3.7 \n Skipping TADGAN")
+                self.models = self.models.remove('TADGAN')
+            else:
+                print("All good we can run on a full speed!")
+                self.models = ['dbscan', 'iforest', 'ThymeBoost', 'ocsvm', 'lof']#, 'tadgan']
 
-        if self.models == ['full']:
-             self.models = ['dbscan', 'iforest', 'ThymeBoost', 'ocsvm', 'lof']
+       
 
 
     # This function will find the best parameters for the given data so that the user can get the best results
